from __future__ import annotations

from spark_auto_mapper_fhir.fhir_types.uri import FhirUri

from spark_auto_mapper_fhir.base_types.FhirValueSetBase import FhirValueSetBase
from spark_auto_mapper.type_definitions.defined_types import AutoMapperTextInputType


# This file is auto-generated by generate_classes so do not edit manually
# noinspection PyPep8Naming
class IdentifierTypeCodesCode(FhirValueSetBase):
    """
    Identifier Type Codes
    """

    def __init__(self, value: AutoMapperTextInputType):
        super().__init__(value=value)

    """
    http://hl7.org/fhir/ValueSet/identifier-type
    """
    codeset: FhirUri = "http://hl7.org/fhir/ValueSet/identifier-type"


class IdentifierTypeCodesCodeValues:
    """
    None
    """

    DL = IdentifierTypeCodesCode("DL")
    """
    None
    """
    PPN = IdentifierTypeCodesCode("PPN")
    """
    None
    """
    BRN = IdentifierTypeCodesCode("BRN")
    """
    None
    """
    MR = IdentifierTypeCodesCode("MR")
    """
    None
    """
    MCN = IdentifierTypeCodesCode("MCN")
    """
    None
    """
    EN = IdentifierTypeCodesCode("EN")
    """
    None
    """
    TAX = IdentifierTypeCodesCode("TAX")
    """
    None
    """
    NIIP = IdentifierTypeCodesCode("NIIP")
    """
    None
    """
    PRN = IdentifierTypeCodesCode("PRN")
    """
    None
    """
    MD = IdentifierTypeCodesCode("MD")
    """
    None
    """
    DR = IdentifierTypeCodesCode("DR")
    """
    None
    """
    ACSN = IdentifierTypeCodesCode("ACSN")
    """
    None
    """
    UDI = IdentifierTypeCodesCode("UDI")
    """
    None
    """
    SNO = IdentifierTypeCodesCode("SNO")
    """
    None
    """
    SB = IdentifierTypeCodesCode("SB")
    """
    None
    """
    PLAC = IdentifierTypeCodesCode("PLAC")
    """
    None
    """
    FILL = IdentifierTypeCodesCode("FILL")
    """
    None
    """
    JHN = IdentifierTypeCodesCode("JHN")

    # these are manually created for ease of use
    AccreditationCertificationIdentifier = IdentifierTypeCodesCode("AC")

    AmericanMedicalAssociationNumber = IdentifierTypeCodesCode("AMA")

    AccountNumber = IdentifierTypeCodesCode("AN")

    AccountNumberCreditor = IdentifierTypeCodesCode("ANC")

    AccountNumberDebitor = IdentifierTypeCodesCode("AND")

    AnonymousIdentifier = IdentifierTypeCodesCode("ANON")

    """
    Class: Financial
    Temporary version of an Account Number.
    Use Case: An ancillary system that does not normally assign account numbers is the first time
     to register a patient. This ancillary system will generate a temporary account number that will
     only be used until an official account number is assigned.
    """
    TemporaryAccountNumber = IdentifierTypeCodesCode("ANT")

    BankAccountNumber = IdentifierTypeCodesCode("BA")

    BankCardNumber = IdentifierTypeCodesCode("BC")

    BirthCertificateFileNumber = IdentifierTypeCodesCode("BCFN")

    """
    A number associated with a document identifying the event of a person's birth.
    """
    BirthCertificate = IdentifierTypeCodesCode("BCT")

    """
    An identifier unique within the Assigning Authority that is the official legal record of a person's birth.
    """
    BirthRegistryNumber = IdentifierTypeCodesCode("BR")

    """
    Class: Financial
    Use Case: needed especially for transmitting information about invoices.
    """
    CostCenterNumber = IdentifierTypeCodesCode("CC")

    """
    A number associated with a document identifying a person's legal change of name.
    """
    ChangeOfNameDocument = IdentifierTypeCodesCode("CONM")

    CountyNumber = IdentifierTypeCodesCode("CY")

    """
    A number assigned by a person's country of residence to identify a person's citizenship.
    """
    CitizenshipCard = IdentifierTypeCodesCode("CZ")

    DeathCertificateId = IdentifierTypeCodesCode("DC")

    DeathCertificateFileNumber = IdentifierTypeCodesCode("DCFN")

    """
    An identifier that is unique to a dentist within the jurisdiction of the licensing board
    """
    DentistLicenseNumber = IdentifierTypeCodesCode("DDS")

    """
    An identifier for an individual or organization relative to controlled substance regulation and transactions.
    Use case: This is a registration number that identifies an individual or organization relative to
    controlled substance regulation and transactions. A DEA number has a very precise and widely accepted
     meaning within the United States. Surprisingly, the US Drug Enforcement Administration does not
     solely assign DEA numbers in the United States. Hospitals have the authority to issue DEA numbers
      to their medical residents. These DEA numbers are based upon the hospital’s DEA number,
      but the authority rests with the hospital on the assignment to the residents.
      Thus, DEA as an Identifier Type is necessary in addition to DEA as an Assigning Authority.
    """
    DrugEnforcementAdministrationRegistrationNumber = IdentifierTypeCodesCode("DEA")

    DrugFurnishingOrPrescriptiveAuthorityNumber = IdentifierTypeCodesCode("DFN")

    DriverLicenseNumber = IdentifierTypeCodesCode("DL")

    DoctorNumber = IdentifierTypeCodesCode("DN")

    """
    An identifier that is unique to an osteopath within the jurisdiction of a licensing board.
    """
    OsteopathicLicenseNumber = IdentifierTypeCodesCode("DO")

    """
    An identifier that is unique to a podiatrist within the jurisdiction of the licensing board.
    """
    PodiatristLicenseNumber = IdentifierTypeCodesCode("DPM")

    """
    A number that uniquely identifies an employee to an employer.
    """
    EmployeeId = IdentifierTypeCodesCode("EI")

    EmployerNumber = IdentifierTypeCodesCode("EN")

    """
    An identifier that is unique to a staff member within an enterprise (as identified by the Assigning Authority).
    """
    StaffEnterpriseNumber = IdentifierTypeCodesCode("ESN")

    FacilityId = IdentifierTypeCodesCode("FI")

    GuarantorInternalIdentifier = IdentifierTypeCodesCode("GI")

    GeneralLedgerNumber = IdentifierTypeCodesCode("GL")

    GuarantorExternalIdentifier = IdentifierTypeCodesCode("GN")

    HealthCardNumber = IdentifierTypeCodesCode("HC")

    LicenseNumber = IdentifierTypeCodesCode("LN")

    PatientMedicaidNumber = IdentifierTypeCodesCode("MA")

    """
    An identifier for the insured of an insurance policy (this insured always has a subscriber),
    usually assigned by the insurance carrier. Use Case: Person is covered by an insurance policy.
    This person may or may not be the subscriber of the policy.
    """
    MemberNumber = IdentifierTypeCodesCode("MB")

    """
    Patient's Medicare number. Class: Insurance
    """
    PatientMedicareNumber = IdentifierTypeCodesCode("MC")

    """
    Practitioner Medicaid number. Class: Insurance
    """
    PractitionerMedicaidNumber = IdentifierTypeCodesCode("MCD")

    """
    Practitioner Medicare number. Class: Insurance
    """
    PractitionerMedicareNumber = IdentifierTypeCodesCode("MCR")

    """
    An identifier that is unique to a medical doctor within the jurisdiction of a licensing board.
    Use Case: These license numbers are sometimes used as identifiers. In some states,
    the same authority issues all three identifiers, e.g., medical, osteopathic, and
    physician assistant licenses all issued by one state medical board.
    For this case, the CX data type requires distinct identifier types to accurately interpret component
    1. Additionally, the distinction among these license types is critical in most health care settings
    (this is not to convey full licensing information, which requires a segment to support all related attributes).
    """
    MedicalLicenseNumber = IdentifierTypeCodesCode("MD")

    """
    A number assigned to an individual who has had military duty, but is not currently on active duty.
    The number is assigned by the DOD or Veterans' Affairs (VA).
    """
    MilitaryIdNumber = IdentifierTypeCodesCode("MI")

    """
    An identifier that is unique to a patient within a set of medical records,
    not necessarily unique within an application.
    """
    MedicalRecordNumber = IdentifierTypeCodesCode("MR")

    """
    Temporary version of a Medical Record Number
    Use Case: An ancillary system that does not normally assign medical record numbers
    is the first time to register a patient. This ancillary system will generate a temporary
    medical record number that will only be used until an official medical record number is assigned.
    """
    TemporaryMedicalRecordNumber = IdentifierTypeCodesCode("MRT")

    """
    A number associated with a document identifying a person's retention of citizenship in a particular country.
    """
    NaturalizationCertificate = IdentifierTypeCodesCode("NCT")

    """
     In the US, the Assigning Authority for this value is typically CMS, but it may be used by all providers
      and insurance companies in HIPAA related transactions.
     """
    NationalEmployerIdentifier = IdentifierTypeCodesCode("NE")

    """
    Class: Insurance
    Used for the UK NHS national identifier.
    In the US, the Assigning Authority for this value is typically CMS, but it may be used by
    all providers and insurance companies in HIPAA related transactions.
    """
    NationalHealthPlanIdentifier = IdentifierTypeCodesCode("NH")

    """
    An identifier that is unique to a nurse practitioner within the jurisdiction of a certifying board.
    """
    NationalUniqueIndividualIdentifier = IdentifierTypeCodesCode("NI")

    """
    An identifier that is unique to a nurse practitioner within the jurisdiction of a certifying board.
    """
    NursePractitionerNumber = IdentifierTypeCodesCode("NP")

    """
    Class: Insurance In the US, the Assigning Authority for this value is typically CMS,
    but it may be used by all providers and insurance companies in HIPAA related transactions.
    """
    NationalProviderIdentifier = IdentifierTypeCodesCode("NPI")

    """
    A number that is unique to an individual optometrist within the jurisdiction of the licensing board.
    """
    OptometristLicenseNumber = IdentifierTypeCodesCode("OD")

    """
    An identifier that is unique to a physician assistant within the jurisdiction of a licensing board
    """
    PhysicianAssistantNumber = IdentifierTypeCodesCode("PA")

    PensionNumber = IdentifierTypeCodesCode("PEN")

    """
    A number that is unique to a patient within an Assigning Authority.
    """
    PatientInternalIdentifier = IdentifierTypeCodesCode("PI")

    """
    A number that is unique to a living subject within an Assigning Authority.
    """
    PersonNumber = IdentifierTypeCodesCode("PN")

    """
    A unique number assigned to the document affirming that a person is a citizen of the country.
    In the US this number is issued only by the State Department.
    """
    PassportNumber = IdentifierTypeCodesCode("PPN")

    ProviderNumber = IdentifierTypeCodesCode("PRN")

    PatientExternalIdentifier = IdentifierTypeCodesCode("PT")

    """
    A generalized resource identifier. Use Case: An identifier type is needed to accommodate
    what are commonly known as resources. The resources can include human (e.g. a respiratory therapist),
    non-human (e.g., a companion animal), inanimate object (e.g., an exam room),
    organization (e.g., diabetic education class) or any other physical or logical entity.
    """
    ResourceIdentifier = IdentifierTypeCodesCode("RI")

    SocialBeneficiaryIdentifier = IdentifierTypeCodesCode("SB")

    """
    Identifier for a specimen. Used when it is not known if the specimen ID is a unique specimen ID (USID)
    or an ancestor ID (ASID).
    """
    SpecimenId = IdentifierTypeCodesCode("SID")

    StateLicense = IdentifierTypeCodesCode("SL")

    """
    Class: Insurance An identifier for a subscriber of an insurance policy which is unique for,
    and usually assigned by, the insurance carrier.
    Use Case: A person is the subscriber of an insurance policy.
    The person’s family may be plan members, but are not the subscriber.
    """
    SubscriberNumber = IdentifierTypeCodesCode("SN")

    SerialNumber = IdentifierTypeCodesCode("SNO")

    StateRegistryId = IdentifierTypeCodesCode("SR")

    """
    Social Security number
    """
    SocialSecurityNumber = IdentifierTypeCodesCode("SS")

    ShipmentTrackingNumber = IdentifierTypeCodesCode("STN")

    TaxIdNumber = IdentifierTypeCodesCode("TAX")

    TrainingLicenseNumber = IdentifierTypeCodesCode("TRL")

    UnspecifiedIdentifier = IdentifierTypeCodesCode("U")

    UniversalDeviceIdentifier = IdentifierTypeCodesCode("UDI")

    """
    Class: Insurance
    An identifier for a provider within the CMS/Medicare program.
    A globally unique identifier for the provider in the Medicare program.
    """
    UniversalPhysicianIdentificationNumber = IdentifierTypeCodesCode("UPIN")

    VisitNumber = IdentifierTypeCodesCode("VN")

    WICIdentifier = IdentifierTypeCodesCode("WC")

    WorkersCompNumber = IdentifierTypeCodesCode("WCN")

    HealthPlanIdentifier = IdentifierTypeCodesCode("XV")

    OrganizationIdentifier = IdentifierTypeCodesCode("XX")
